Creating and using an interactive InferenceSession with the Python client
=========================================================================

.. literalinclude :: create-inferencesession.py
    :language: python
